pub async fn get_memory_system() -> Result<Arc<ConversationMemorySystem>>Expand description
Return the global memory system, lazily initialising it if needed.
pub async fn get_memory_system() -> Result<Arc<ConversationMemorySystem>>Return the global memory system, lazily initialising it if needed.