Module session

Module session 

Session lifecycle: create, load, checkpoint, list, search, metadata. Session lifecycle: create, load, checkpoint, list, search, and metadata.

Functions

create_session_checkpoint
Create a session checkpoint using the global memory system.
create_session_checkpoint_with_system
Create a session checkpoint using an explicit memory system reference.
list_sessions
List all sessions via the global memory system.
list_sessions_with_storage
List all persisted sessions using a direct storage reference.
load_session
Load a session by ID via the global memory system.
load_session_checkpoint
Load a session checkpoint using the global memory system.
load_session_checkpoint_with_system
Load a session from a previously saved checkpoint.
load_session_with_system
Load a session by ID using an explicit memory system reference.
mark_important
Mark a specific context update as important within a session.
search_sessions
Search sessions by name or description.
update_session_metadata
Update the name and/or description of a session.