pub async fn create_session_checkpoint(
session_id: Uuid,
) -> Result<MCPToolResult>Expand description
Create a session checkpoint using the global memory system.
pub async fn create_session_checkpoint(
session_id: Uuid,
) -> Result<MCPToolResult>Create a session checkpoint using the global memory system.