pub async fn create_workspace(
name: String,
description: String,
) -> Result<MCPToolResult>Expand description
Create a new workspace with the given name and description.
pub async fn create_workspace(
name: String,
description: String,
) -> Result<MCPToolResult>Create a new workspace with the given name and description.