Session lifecycle: create, load, checkpoint, list, search, metadata. Session lifecycle: create, load, checkpoint, list, search, and metadata.
Functions
- create_
session_ checkpoint - Create a session checkpoint using the global memory system.
- create_
session_ checkpoint_ with_ system - Create a session checkpoint using an explicit memory system reference.
- list_
sessions - List all sessions via the global memory system.
- list_
sessions_ with_ storage - List all persisted sessions using a direct storage reference.
- load_
session - Load a session by ID via the global memory system.
- load_
session_ checkpoint - Load a session checkpoint using the global memory system.
- load_
session_ checkpoint_ with_ system - Load a session from a previously saved checkpoint.
- load_
session_ with_ system - Load a session by ID using an explicit memory system reference.
- mark_
important - Mark a specific context update as important within a session.
- search_
sessions - Search sessions by name or description.
- update_
session_ metadata - Update the name and/or description of a session.